<template><div>
    <div style="position:relative;width:100%;height:100%;">
        <!--标头-->
        <div style="margin-bottom:0;z-index:999999;box-shadow: 0 4px 8px rgba(0, 0, 0, 0);left:0;right:4vh;background:transparent;" :style="ASDN66?.dark ? { color: 'white' } : { color: 'black' }">
            <div class="order_header" style="height:4vh;line-height:8vh;padding-top:0;">
                <div class="order_header_item">订单ID</div>
                <div class="order_header_item">已下提货量</div>
                <div class="order_header_item">进度</div>
                <div class="order_header_item">
                    <button class="edit-button confirm" style="width:4vh;border-radius: 4vh;background-color: #4CAF50;color: white;margin-left:0;height:2.5vh;padding:0;">+</button>
                </div>
            </div>
        </div>
        <!--标头结束-->

        <div class="orders_list" style="margin-top: 0vh; height: 45vh;" :style="ASDN66?.dark ? { color: 'white' } : { color: 'black' }">
            <div v-for="(item, index) in filteredOrders" :key="index" :class="['order', { 'expanded': expandedOrder === index }]" class="shadow" :style="ASDN66?.dark ? null : { background: 'white', color: 'black' }" @mousedown="order_list_menu(item)" @touchstart="order_list_menu(item)">
                <div class="order_header">
                    <div class="order_header_item"><input :readonly="!isEditing(index)" :class="{ 'editable': isEditing(index) }" v-model="item.order_id" /></div>
                    <div class="order_header_item"><textarea :readonly="!isEditing(index)" :class="{ 'editable': isEditing(index) }" v-model="item.pickup_quantity"></textarea></div>
                    <div class="order_header_item"><textarea :readonly="!isEditing(index)" :class="{ 'editable': isEditing(index) }" v-model="item.status"></textarea></div>
                    <div class="order_header_item">
                        <div @click.stop="toggleOrder(index)">
                            {{ expandedOrder === index ? '收起' : '展开' }}
                        </div>
                    </div>
                </div>

                <!--详细数据-->
                <div class="order_details" :style="expandedOrder === index?{opacity:1}:{opacity:0}">
                    <p>更多详细信息...</p>
                    <div>2024-06-13 12:30 签订合同</div>
                    <div>2024-06-13 12:51 汇保证金20万</div>
                    <div>2024-06-13 13:22 下达33吨提货计划</div>
                    <div>2024-06-13 14:16 下达33吨提货计划</div>
                    <div v-for="pickup in getPickupsByOrderId(item.order_id)"></div>

                    <PickupComponent :pickups="getPickupsByOrderId(item.order_id)"></PickupComponent>
                    
                    <div class="order_header_item">订单ID：<textarea :readonly="!isEditing(index)" :class="{ 'editable': isEditing(index) }" v-model="item.order_id"></textarea></div>
                    <div class="edit-buttons">
                        <button class="edit-button cancel" @click="startEditing(index)">
                            {{ isEditing(index) ? '取消' : '编辑' }}
                        </button>
                        <button class="edit-button confirm" v-if="isEditing(index)" @click="confirmEdit(index,item.id)">确认</button>
                    </div>
                </div>
                <!--详细数据结束-->

            </div>
            
            <!--空div,占位-->
            <div style="position:relative;height:10vmin;"></div>
            
        </div>
    
    <add_pickup_component v-show="data.add_pickup_data?.visible" v-model:data="data.add_pickup_data"></add_pickup_component>
    
    </div>
</div></template>

<script setup>
import { ref, reactive, inject, provide } from 'vue';
import { loadModule } from 'vue3-sfc-loader';
const p_c = inject('p_c');//data为父组件传递数据

const ASDN66 = inject('ASDN66'); // 黑白模式
const expandedOrder = ref(null);
const editingIndex = ref(null);
const originalData = reactive({});

const data = reactive({
    add_pickup_data:{
        visible:false,
    }
})

socket.emit('join_room_orders')
socket.on('connect', (data) => {
    socket.emit('join_room_orders')
});

socket.on('orders', (orders) => {
    console.log('收到新订单列表', orders)
    p_c.orders = orders;
    
    data.orders = orders;
})

//自己或其他用户新增了订单,从服务器得到反馈,更新列表
socket.on('add_order', (orders) => {
    console.log('收到add_order', orders)
    data.orders.push(orders)
})

//若p_c.selectedClass不为null，则v-for p_c.orders中class为p_c.selectedClass的数据，若p_c.selectedClass为null则v-for所有p_c.orders
const filteredOrders = computed(() => {
  if (p_c.selectedClass) {
    return p_c.orders.filter(order => order.class === p_c.selectedClass);
  } else {
    return p_c.orders;
  }
});


//展开/收起
const toggleOrder = (index) => {
    expandedOrder.value = (expandedOrder.value === index) ? null : index;
};

const isEditing = (index) => {
    return editingIndex.value === index;
};

const startEditing = (index) => {
    if (editingIndex.value === index) {
        cancelEdit();
    } else {
        editingIndex.value = index;
        originalData[index] = { ...data.orders[index] };
    }
};

const confirmEdit = (index,id) => {
    editingIndex.value = null;
    // 自定义函数2
    console.log('确认编辑，数据已保存');
};

const cancelEdit = () => {
    if (editingIndex.value !== null) {
        data.orders[editingIndex.value] = { ...originalData[editingIndex.value] };
    }
    editingIndex.value = null;
    console.log('取消编辑，数据未保存');
};

const getPickupsByOrderId = (orderId) => {
    console.log(orderId)
  //return data.pickup.filter(pickup => pickup.order_id === orderId);
};

//add_pickup子组件部分
function add_pickup_edit(item){
    data.add_pickup_data.visible = true;
    data.add_pickup_data.order_id = item.order_id;  //采购订单ID
}

const OneStep = inject('OneStep');

function order_list_menu(item){
    OneStep.show(event, [
  {
    name: '新增提货',
    direction: 'y',
    width: 100,height: 50,
    children: [
      { 
        name: '车提', 
        direction: 'x', 
        width: 150,height: 50,
        children: [
          { name: '三级菜单1', direction: 'y', width: 100,height: 50, }, 
          { name: '三级菜单2', direction: 'y', width: 100,height: 50, },
        ],
        fun: () => { console.log(1111111);console.log(item);add_pickup_edit(item) },
      },
      { name: '船提', direction: 'x', width: 150,height: 50,
        children: [
          { name: '三级菜单1', direction: 'y', width: 100,height: 50, }, 
          { name: '三级菜单2', direction: 'y', width: 100,height: 50, },
        ],
      },
      { name: '管输', direction: 'x', width: 150,height: 50, }
    ]
  },

    {
        name: '收付款',
        direction: 'y',
        width: 100,height: 50,
        children: [
          { 
            name: '收款', direction: 'x', width: 150,height: 50,
            fun: () => { console.log('收款窗口弹出');console.log(item); },
          },
          { name: '付款', direction: 'x', width: 150,height: 50, 
            fun: () => { console.log('付款窗口弹出');console.log(item); },
          },
        ]
    },


    { name: '结算合同', direction: 'y', width: 100,height: 50, },
    { 
        name: '删改数据', direction: 'y', width: 100,height: 50,
        children: [
            {
                name: '修改数据', direction: 'x', width: 100,height: 50,
                fun: () => {
                    
                    socket.emit('change_order',item)
                }
            }, 
            { 
                name: '删除订单', direction: 'x', width: 100,height: 50,
                fun: () => { socket.emit('delete_order',item) }
            },
        ],
    },
],'x');
}

const PickupComponent = Vue.defineAsyncComponent(() => loadModule('/vue/body/commerce/pickup.vue', options));

const add_pickup_component = Vue.defineAsyncComponent(() => loadModule('/vue/body/commerce/pickup/add_pickup.vue', options));

</script>

<style scoped>
* {
    transition: 0.6s;
}
.fade-enter-active, .fade-leave-active {
    transition: opacity 0.4s;
}
.fade-enter, .fade-leave-to /* .fade-leave-active in <2.1.8 */ {
  opacity: 0;
}

.order {
    background: #222222;
    color: white;
    border-radius: 4vh;
    margin-bottom: 2vh;
    box-shadow: 0 2px 5px rgba(0, 0, 0, 0.1);
    overflow: hidden;
    position: relative;
    height: 10vh; /* 初始高度 */
}

.order.expanded {
    height: 52vh; /* 展开后的高度 */
}
.order_header {
    display: flex;
    justify-content: space-around;
    align-items: center; /* 确保垂直居中对齐 */
    height: 10vh;
    margin: 0;
}

.order_details {
    display: flex;
    flex-direction: column;
    align-items: center;
    padding: 1vh;
}

.order_header_item {
    flex: 1;
    text-align: center;
    margin: 0 10px;
    overflow: hidden; /* 隐藏超出部分 */
    text-overflow: ellipsis; /* 显示省略号 */
    white-space: nowrap; /* 防止文字换行 */
    display: flex; /* 添加 flex 布局 */
    align-items: center; /* 确保内容垂直居中 */
    justify-content: center; /* 确保内容水平居中 */
}

.edit-buttons {
    display: flex;
    justify-content: space-between;
    width: 100%;
    margin-top: 1vh;
}

.edit-button {
    border: none;
    border-radius: 20px;
    padding: 0.5vh 2vh;
    cursor: pointer;
}

.edit-button.cancel {
    background-color: #555;
    color: white;
}

.edit-button.confirm {
    background-color: #4CAF50;
    color: white;
    margin-left: 1vh; /* 添加一点间隙 */
}

.edit-button.cancel:hover {
    background-color: #777;
}

.edit-button.confirm:hover {
    background-color: #45a049;
}

textarea, input {
    color: inherit;
    border: none;
    background: transparent;
    resize: none;
    pointer-events: none; /* 禁止编辑 */
    font-size: 1.5vh;
    font-weight: 600;
    line-height: 2vh;
    height: 2vh;
    text-align: center;
}

textarea.editable, input.editable {
    border: 1px solid #ccc;
    pointer-events: auto; /* 允许编辑 */
}

/* 横屏样式 */
@media only screen and (orientation: landscape) {
    .main {
        font-weight: 600;
        background: #E9E9E9;
        padding: 4vh;
        font-family: Arial, sans-serif;
    }
    .orders_list {
        position: relative;
        overflow-x: hidden;
        overflow-y: auto;
        touch-action:pan-y;
        
    }
}

/* 竖屏样式 */
@media only screen and (orientation: portrait) {
    .main {
        background: #E9E9E9;
        padding: 2vh;
        font-family: Arial, sans-serif;
    }
    .orders_list {
        position: relative;
        overflow-x: hidden;
        overflow-y: auto;
        
    }
}
</style>